==> knative-model-4.6.3-sources.jar: io/fabric8/knative/serving/v1beta1/ConfigurationListFluentImpl.java <==
package io.fabric8.knative.serving.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class ConfigurationListFluentImpl<A extends io.fabric8.knative.serving.v1beta1.ConfigurationListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.knative.serving.v1beta1.ConfigurationListFluent<A>{

    private String apiVersion;
    private List<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> items;
    private String kind;
    private ListMeta metadata;

    public ConfigurationListFluentImpl(){
    }
    public ConfigurationListFluentImpl(io.fabric8.knative.serving.v1beta1.ConfigurationList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,io.fabric8.knative.serving.v1beta1.Configuration item){
            if (this.items == null) {this.items = new ArrayList<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder>();}
            io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,io.fabric8.knative.serving.v1beta1.Configuration item){
            if (this.items == null) {this.items = new ArrayList<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder>();}
            io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(item);
            if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(io.fabric8.knative.serving.v1beta1.Configuration... items){
            if (this.items == null) {this.items = new ArrayList<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder>();}
            for (io.fabric8.knative.serving.v1beta1.Configuration item : items) {io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<io.fabric8.knative.serving.v1beta1.Configuration> items){
            if (this.items == null) {this.items = new ArrayList<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder>();}
            for (io.fabric8.knative.serving.v1beta1.Configuration item : items) {io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(io.fabric8.knative.serving.v1beta1.Configuration... items){
            for (io.fabric8.knative.serving.v1beta1.Configuration item : items) {io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<io.fabric8.knative.serving.v1beta1.Configuration> items){
            for (io.fabric8.knative.serving.v1beta1.Configuration item : items) {io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.knative.serving.v1beta1.Configuration> getItems(){
            return build(items);
    }

    public List<io.fabric8.knative.serving.v1beta1.Configuration> buildItems(){
            return build(items);
    }

    public io.fabric8.knative.serving.v1beta1.Configuration buildItem(int index){
            return this.items.get(index).build();
    }

    public io.fabric8.knative.serving.v1beta1.Configuration buildFirstItem(){
            return this.items.get(0).build();
    }

    public io.fabric8.knative.serving.v1beta1.Configuration buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public io.fabric8.knative.serving.v1beta1.Configuration buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> predicate){
            for (io.fabric8.knative.serving.v1beta1.ConfigurationBuilder item: items) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> predicate){
            for (io.fabric8.knative.serving.v1beta1.ConfigurationBuilder item: items) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withItems(List<io.fabric8.knative.serving.v1beta1.Configuration> items){
            if (this.items != null) { _visitables.get("items").removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder>(); for (io.fabric8.knative.serving.v1beta1.Configuration item : items){this.addToItems(item);}} else { this.items = new ArrayList<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder>();} return (A) this;
    }

    public A withItems(io.fabric8.knative.serving.v1beta1.Configuration... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (io.fabric8.knative.serving.v1beta1.Configuration item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public ConfigurationListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public ConfigurationListFluent.ItemsNested<A> addNewItemLike(io.fabric8.knative.serving.v1beta1.Configuration item){
            return new ItemsNestedImpl(-1, item);
    }

    public ConfigurationListFluent.ItemsNested<A> setNewItemLike(int index,io.fabric8.knative.serving.v1beta1.Configuration item){
            return new ItemsNestedImpl(index, item);
    }

    public ConfigurationListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public ConfigurationListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public ConfigurationListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public ConfigurationListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata(){
            return this.metadata;
    }

    public A withMetadata(ListMeta metadata){
            this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ConfigurationListFluentImpl that = (ConfigurationListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends io.fabric8.knative.serving.v1beta1.ConfigurationFluentImpl<ConfigurationListFluent.ItemsNested<N>> implements ConfigurationListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,io.fabric8.knative.serving.v1beta1.Configuration item){
                    this.index = index;
                    this.builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationListFluentImpl.this.setToItems(index, builder.build());
    }
    public N endItem(){
            return and();
    }

}


}

==> knative-model-4.10.1-sources.jar: io/fabric8/knative/serving/v1beta1/ConfigurationListFluentImpl.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class ConfigurationListFluentImpl<A extends io.fabric8.knative.serving.v1beta1.ConfigurationListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.knative.serving.v1beta1.ConfigurationListFluent<A>{

    private String apiVersion;
    private List<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> items;
    private String kind;
    private ListMeta metadata;

    public ConfigurationListFluentImpl(){
    }
    public ConfigurationListFluentImpl(io.fabric8.knative.serving.v1beta1.ConfigurationList instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withItems(instance.getItems()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,io.fabric8.knative.serving.v1beta1.Configuration item){
            if (this.items == null) {this.items = new ArrayList<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder>();}
            io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,io.fabric8.knative.serving.v1beta1.Configuration item){
            if (this.items == null) {this.items = new ArrayList<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder>();}
            io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(item);
            if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
            if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
             return (A)this;
    }

    public A addToItems(io.fabric8.knative.serving.v1beta1.Configuration... items){
            if (this.items == null) {this.items = new ArrayList<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder>();}
            for (io.fabric8.knative.serving.v1beta1.Configuration item : items) {io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<io.fabric8.knative.serving.v1beta1.Configuration> items){
            if (this.items == null) {this.items = new ArrayList<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder>();}
            for (io.fabric8.knative.serving.v1beta1.Configuration item : items) {io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(io.fabric8.knative.serving.v1beta1.Configuration... items){
            for (io.fabric8.knative.serving.v1beta1.Configuration item : items) {io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<io.fabric8.knative.serving.v1beta1.Configuration> items){
            for (io.fabric8.knative.serving.v1beta1.Configuration item : items) {io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> predicate){
            if (items == null) return (A) this;
            final Iterator<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> each = items.iterator();
            final List visitables = _visitables.get("items");
            while (each.hasNext()) {
              io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public List<io.fabric8.knative.serving.v1beta1.Configuration> getItems(){
            return build(items);
    }

    public List<io.fabric8.knative.serving.v1beta1.Configuration> buildItems(){
            return build(items);
    }

    public io.fabric8.knative.serving.v1beta1.Configuration buildItem(int index){
            return this.items.get(index).build();
    }

    public io.fabric8.knative.serving.v1beta1.Configuration buildFirstItem(){
            return this.items.get(0).build();
    }

    public io.fabric8.knative.serving.v1beta1.Configuration buildLastItem(){
            return this.items.get(items.size() - 1).build();
    }

    public io.fabric8.knative.serving.v1beta1.Configuration buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> predicate){
            for (io.fabric8.knative.serving.v1beta1.ConfigurationBuilder item: items) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> predicate){
            for (io.fabric8.knative.serving.v1beta1.ConfigurationBuilder item: items) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withItems(List<io.fabric8.knative.serving.v1beta1.Configuration> items){
            if (this.items != null) { _visitables.get("items").removeAll(this.items);}
            if (items != null) {this.items = new ArrayList<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder>(); for (io.fabric8.knative.serving.v1beta1.Configuration item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(io.fabric8.knative.serving.v1beta1.Configuration... items){
            if (this.items != null) {this.items.clear();}
            if (items != null) {for (io.fabric8.knative.serving.v1beta1.Configuration item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems(){
            return items != null && !items.isEmpty();
    }

    public ConfigurationListFluent.ItemsNested<A> addNewItem(){
            return new ItemsNestedImpl();
    }

    public ConfigurationListFluent.ItemsNested<A> addNewItemLike(io.fabric8.knative.serving.v1beta1.Configuration item){
            return new ItemsNestedImpl(-1, item);
    }

    public ConfigurationListFluent.ItemsNested<A> setNewItemLike(int index,io.fabric8.knative.serving.v1beta1.Configuration item){
            return new ItemsNestedImpl(index, item);
    }

    public ConfigurationListFluent.ItemsNested<A> editItem(int index){
            if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
            return setNewItemLike(index, buildItem(index));
    }

    public ConfigurationListFluent.ItemsNested<A> editFirstItem(){
            if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
            return setNewItemLike(0, buildItem(0));
    }

    public ConfigurationListFluent.ItemsNested<A> editLastItem(){
            int index = items.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
            return setNewItemLike(index, buildItem(index));
    }

    public ConfigurationListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1beta1.ConfigurationBuilder> predicate){
            int index = -1;
            for (int i=0;i<items.size();i++) { 
            if (predicate.apply(items.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
            return setNewItemLike(index, buildItem(index));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata(){
            return this.metadata;
    }

    public A withMetadata(ListMeta metadata){
            this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink){
            return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ConfigurationListFluentImpl that = (ConfigurationListFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (items != null ? !items.equals(that.items) :that.items != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            return true;
    }


    public class ItemsNestedImpl<N> extends io.fabric8.knative.serving.v1beta1.ConfigurationFluentImpl<ConfigurationListFluent.ItemsNested<N>> implements ConfigurationListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final io.fabric8.knative.serving.v1beta1.ConfigurationBuilder builder;
        private final int index;
    
            ItemsNestedImpl(int index,io.fabric8.knative.serving.v1beta1.Configuration item){
                    this.index = index;
                    this.builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(this, item);
            }
            ItemsNestedImpl(){
                    this.index = -1;
                    this.builder = new io.fabric8.knative.serving.v1beta1.ConfigurationBuilder(this);
            }
    
    public N and(){
            return (N) ConfigurationListFluentImpl.this.setToItems(index,builder.build());
    }
    public N endItem(){
            return and();
    }

}


}
